@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2008-2018, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2020, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -505,11 +505,14 @@ use old releases of this bindings.
 
 `Homepage <https://www.jcea.es/programacion/
 pybsddb.htm>`__ --
+`Releases (changelog) <https://www.jcea.es/programacion/
+pybsddb.htm#Releases>`__ --
 `Documentation <https://www.jcea.es/programacion/
 pybsddb_doc/>`__ --
 `Mailing List <https://mailman.jcea.es/listinfo/pybsddb>`__ --
 `Donation <https://www.jcea.es/programacion/pybsddb_doc/donate.html>`__
 """,
+      long_description_content_type = 'text/x-rst',
 
       author = 'Jesus Cea, Robin Dunn, Gregory P. Smith, Andrew Kuchling, Barry Warsaw',
       author_email = 'pybsddb@jcea.es',
@@ -551,6 +554,8 @@ pybsddb_doc/>`__ --
                     'Programming Language :: Python :: 3.5',
                     'Programming Language :: Python :: 3.6',
                     'Programming Language :: Python :: 3.7',
+                    'Programming Language :: Python :: 3.8',
+                    'Programming Language :: Python :: 3.9',
                     ],
       )
 
