@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2008-2018, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2020, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,8 @@ import os
 os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
 
 def do_matrix_check() :
-  python_versions = ('2.6', '2.7', '3.3', '3.4', '3.5', '3.6', '3.7')
+  python_versions = ('2.6', '2.7',
+                     '3.3', '3.4', '3.5', '3.6', '3.7', 3.8', '3.9')
   berkeleydb_versions=('4.7', '4.8',
                        '5.1', '5.3',
                        '6.1', '6.2')
